UnsupportedFeatureException class
The archive uses a feature this implementation does not (yet) support (e.g. ZIP64 before M7, GNU sparse tars, multi-volume archives).
- Inheritance
-
- Object
- ArchiveException
- UnsupportedFeatureException
- Implementers
Constructors
- UnsupportedFeatureException(String message, {String? format, int? offset, String? entryPath})
- Creates an UnsupportedFeatureException.
Properties
- entryPath → String?
-
Normalized path of the entry the problem relates to, when applicable.
finalinherited
- format → String?
-
Name of the archive format being parsed (e.g.
zip), when known.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the problem.
finalinherited
- offset → int?
-
Byte offset into the archive where the problem was detected, when known.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited